@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11482 2019-04-24 02:41:32Z Lavender $
+# $Id: __init__.py 11731 2019-10-02 16:41:15Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-24 11:41:32 +0900 (週三, 24 四月 2019) $
-# $Revision: 11482 $
+# $Date: 2019-10-03 01:41:15 +0900 (週四, 03 十月 2019) $
+# $Revision: 11731 $
 
 from __future__ import print_function
 
@@ -747,7 +747,8 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'IUNO_CLOUD_BROWSER_SETTINGS': None,
         'IUNO_CLOUD_LOGGING_FILE': None,
         'IUNO_CLOUD_LOGGING_LEVEL': 'DEBUG' if DEBUG else 'INFO',
-        'IUNO_CLOUD_STORAGE_SETTINGS': None
+        'IUNO_CLOUD_STORAGE_SETTINGS': None,
+        'IUNO_CLOUD_METRICS_SETTINGS': None,
     }
 
     update(settingsDict, iunoCloudDefaults)
