@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11702 2019-09-10 19:28:08Z Lavender $
+# $Id: __init__.py 11741 2019-10-08 07:46:25Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-11 03:28:08 +0800 (週三, 11 九月 2019) $
-# $Revision: 11702 $
+# $Date: 2019-10-08 16:46:25 +0900 (週二, 08 十月 2019) $
+# $Revision: 11741 $
 
 import os
 import sys
@@ -504,7 +504,16 @@ def attachSettings(settingsDict, enablePaypal=False):
             raise KeyError("You should also set '%s' value." % str(unsettings))
     
     #=========================================================================
-
+    
+    #=========================================================================
+    # oscar ckeditor dashboard
+    DEFAULT_CKEDITOR_SETTINGS = {
+        'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR': True,
+        'IUNO_SHOP_CONTENT_BLOCK_CKEDITOR': True,
+        'IUNO_SHOP_PAGE_CKEDITOR': True,
+    }
+    update(settingsDict, DEFAULT_CKEDITOR_SETTINGS)
+    
     
 
 def attachShopURLs(settings, urlpatterns):
@@ -525,12 +534,17 @@ def attachShopURLs(settings, urlpatterns):
         # the i18n is the default url settings of django oscar, but generally
         # we are not used.
         url(r'^i18n/', include('django.conf.urls.i18n')),
-        url(r'^checkout/payment/redirect/', views.sendPaymentForm, name="formRedirect"),
+        url(r'^checkout/payment/redirect/', 
+            views.sendPaymentForm, name="formRedirect"),
     )
     if VERSION >= (2, 0, 0):
         from django.apps import apps
         urlpatterns += patterns('',
             url(r'^shop/', include(apps.get_app_config('oscar').urls[0])),
+            url(r'^shop/dashboard/catalogue'
+                r'/products/(?P<pk>\d+)/(?P<action>.*)/$', 
+                staff_member_required(views.ProductPublicView.as_view()),
+                name='dashboardProductPublic')
         )
     else:
         from oscar.app import application as shop
