@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11733 2019-10-02 16:58:07Z Lavender $
+# $Id: forms.py 11741 2019-10-08 07:46:25Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-03 01:58:07 +0900 (週四, 03 十月 2019) $
-# $Revision: 11733 $
+# $Date: 2019-10-08 16:46:25 +0900 (週二, 08 十月 2019) $
+# $Revision: 11741 $
 
 import os
 import hashlib
@@ -45,8 +45,14 @@ _ProductForm = get_class('dashboard.catalogue.forms', 'ProductForm')
 class ProductForm(_ProductForm):
     class Meta:
         model = Product
-        fields = [
-            'title', 'upc', 'description', 'is_discountable', 'structure']
+        
+        if not VERSION >= (2, 0, 0):
+            fields = [
+                'title', 'upc', 'description', 'is_discountable', 'structure']
+        else:
+            fields = [
+                'title', 'upc', 'description', 
+                'is_discountable', 'structure', 'is_public']
             
         if hasattr(settings, 'IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR'):
             if settings.IUNO_SHOP_PRODUCT_DESCRIPTION_CKEDITOR:
@@ -224,7 +230,10 @@ if VERSION >= (2, 0, 0):
                 # OPTION
                 choice = []
                 if ot.optionGroup:
-                    choiceOptions = [o.option for o in ot.optionGroup.options.all()]
+                    choiceOptions = [
+                        o.option 
+                        for o in ot.optionGroup.options.all().order_by('id')]
+                    
                     for c in choiceOptions:
                         choice.append((c, c))
                     
@@ -352,4 +361,5 @@ if VERSION >= (2, 0, 0):
     #apps.BasketConfig.add_view = BasketAddView
     basket_tags.AddToBasketForm = AddToBasketForm
     basket_tags.SimpleAddToBasketForm = SimpleAddToBasketForm
+    
 
