@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11639 2019-06-19 05:13:41Z Lavender $
+# $Id: views.py 11741 2019-10-08 07:46:25Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-06-19 13:13:41 +0800 (週三, 19 六月 2019) $
-# $Revision: 11639 $ 
+# $Date: 2019-10-08 16:46:25 +0900 (週二, 08 十月 2019) $
+# $Revision: 11741 $ 
 
 import json
 import logging
@@ -46,6 +46,7 @@ from paypal.express.views import SuccessResponseView
 from oscar.core.loading import get_model, get_class
 from phonenumber_field.phonenumber import to_python
 from oscar.core.compat import get_user_model
+from oscar import VERSION
 
 from Iuppiter.Encoding import utf8
 from Iuppiter.Encryption import Encryptor
@@ -182,7 +183,7 @@ def download_selected_orders(self, request, orders):
         
         phone = '%s' % order.shipping_address.phone_number
         
-        # #FIXME:
+        # FIXME:
         # 目前電話去掉+886換0是給台灣用的
         row['phone'] = phone.replace('+886', '0')
         
@@ -227,6 +228,55 @@ class OrderManager(models.Manager):
 
 Order.objects = OrderManager()
 
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3273#ticket
+if VERSION >= (2, 0, 0):
+    from oscar.apps.dashboard.catalogue import views as dashboardCatalogueViews
+    from oscar.apps.dashboard.catalogue import \
+        tables as dashboardCatalogueTables
+    from django_tables2 import A, TemplateColumn
+
+    Product = get_model('catalogue', 'Product')
+    _ProductTable = get_class('dashboard.catalogue.tables', 'ProductTable')
+
+    class ProductTable(_ProductTable):
+        isPublic = TemplateColumn(
+            verbose_name=_('Is public'),
+            template_name='shop/tables/ProductRowIsPublic.html',
+            accessor=A('is_public'),
+            order_by='is_public')
+        actions = TemplateColumn(
+            verbose_name=_('Actions'),
+            template_name='shop/tables/ProductRowActions.html',
+            orderable=False)
+
+        class Meta(_ProductTable.Meta):
+            sequence = ('title', 'upc', 'image', 'product_class', 'variants',
+                        'stock_records', '...', 'isPublic', 
+                        'date_updated', 'actions')
+
+    dashboardCatalogueTables.ProductTable = ProductTable  
+    
+    class ProductPublicView(generic.View):
+    
+        def get(self, request, *args, **kwargs):
+            pk = kwargs.get('pk', None)
+            action = kwargs.get('action', None)
+            
+            if pk and action in ['public', 'not_public']:
+                product = Product.objects.get(id=pk)
+                if action == 'public':
+                    product.is_public = True
+                    messages.info(
+                        request, _("Set Product to public successfully."))
+                else:    
+                    product.is_public = False
+                    messages.info(
+                        request, _("Set Product to not public successfully."))
+                product.save()
+                return redirect('dashboard:catalogue-product-list')
+            else:
+                raise Http404()
+
 # https://code.nuwainfo.com/trac/Mercurius/ticket/3156#ticket
 from django.core.mail import send_mail
 from des.models import DynamicEmailConfiguration
